---
name: Feature request
about: Suggest a new or improved feature
title: ''
labels: type/feature request
assignees: ''

---

<!-- Before suggesting a feature, we suggest you also check out https://github.com/aiidateam/AEP -->

### Is your feature request related to a problem? Please describe

<!-- A clear and concise description of what the problem is. e.g. I'm always frustrated when ... -->

### Describe the solution you'd like

<!-- A clear and concise description of what you want to happen. -->

### Describe alternatives you've considered

<!-- A clear and concise description of any alternative solutions or features you've considered. -->

### Additional context

<!-- Add any other context or screenshots about the feature request here. -->
